// +a
// : Basic default antialiasing (threshold 0.3, method 1)
// +a +am2
// : Basic antialising using method 2
// +a0.1
// : More accurate antialiasing, method 1
// +a0.1 +am2
// : More accurate antialiasing, method 2
#declare View_POV_Include_Stack = 1;

#include "metals.inc"
#include "stdinc.inc"
/********************************************==#include "colors.inc"
                                               #include "shapes.inc"
                                               #include "transforms.inc"
                                               #include "consts.inc"
                                               #include "functions.inc"
                                               #include "math.inc"
                                               #include "rand.inc"*/
#include "echo.inc"



////////////////////////////////////////////////////////////Photons
#declare Quality = 2;    // 0-3
#if (Quality > 0)
  #declare Use_Photons = 10;
  #declare Photon_Run = 0; // change to "no" to reuse a map
  #declare Photon_File = "saber_test.ph"
#end

#switch (Quality)
  #case (0)
    #declare Use_Photons = no;
  #break
  #case (1)
    #declare S_val = 0.1;
    #declare M_val = 75;
    #declare T_val = 5;
  #break
  #case (2)
    #declare S_val = 0.025;
    #declare M_val = 500;
    #declare T_val = 10;
  #break
  #case (3)
    #declare S_val = 0.01;
    #declare M_val = 1000;
    #declare T_val = 15;
  #break
#end
#local FT = <0,0,0,.5,.38>;	/* filter/transmit */
#local NORMALS = 0;
#local FB = 0;			/* focal blur if U got the time*/
#local REFLECTIONS = 1;
#local REFRACTION = 0; 	/* 0, nothing; 1.55 glass; 1.33 water etc */
#local MEDIA = 1;
#local CAUSTICS = 1;
#local CAUSTICSgather = 10;
#local CRAZY = 0;

#macro Mater( col )
        material {
            texture {
            pigment { rgbft col + FT }
            //pigment { rgbt 1 }
            #if (NORMALS) normal { bumps .1 scale .002 } #end
            #if (1)
            finish { ambient .06 diffuse .4 brilliance 1.2
                specular .92
                #if (NORMALS)
                roughness .04
                #else
                roughness .01
                #end
                metallic .07
                #if (REFLECTIONS)
                reflection { .06,.5 metallic .07 fresnel 1 exponent 1.2 falloff 2 }
                conserve_energy
                #end
            }
            #end
            }
            interior {
                #if (REFRACTION) ior REFRACTION #end
                fade_power 2 fade_distance .02 fade_color rgbft col+FT
                #if (MEDIA)
                  media {
                               intervals 8 samples 2,6
                               emission 3.81*(col)
                               absorption 12*(1-col)
                               #if (CRAZY) scattering { 0, (col)*7 extinction 1 } #end
                  //scale 1
                               #if (0)
                               density {
                                   bumps scale .002
                                   color_map {[0 rgb 1][.5 rgb 1][.56 rgb 0][1 rgb 0]}
                               }
                               #end
                  }
                #end
            }
        }
        #if (Use_Photons) photons { target refraction on } #end
        hollow
#end


global_settings {
  max_trace_level T_val
  assumed_gamma 2.0
  adc_bailout 1/25     // early bailout for speed
  #if (Use_Photons)
    photons {
      spacing S_val
      media M_val
      max_trace_level T_val
      #if (Photon_Run)
        save_file Photon_File
      #else
        load_file Photon_File
      #end
    }
  #end
}
////////////////////////////////////////////////////////////Photons

 


#declare Final_town    = 1;
#declare Final_space   = 2;
#declare Final_diver   = 3;
#declare Preview_town  = 4;
#declare Preview_space = 5;
#declare Preview_diver = 6;
#declare Building_test = 7;

/////////////////////
#declare Quality = 1;   //
#declare radio = 0;
#declare setting = 4;  // 1 faster   4 final

#include "material.inc"
#include "legolib.pov"
#include "legoadd.pov"
#declare camlookat = <0,36,0>;  
#declare camloc = vaxis_rotate(<-20,57,-250>*2.7,y,10);


camera {    perspective
  location  camloc
  //right=up.eye
  //up=eye.right
  //eye=right.up
  right     vnormalize(vcross(y,camlookat-camloc))//*(image_width/image_height right len = 1 for correct fov
  up        vnormalize(vcross(camlookat-camloc,vnormalize(vcross(y,camlookat-camloc))))*(image_height/image_width)
  direction vnormalize(camlookat-camloc)*(image_height/image_width)
  
  //look_at camlookat
  angle     12
  rotate    z*15
  
  #if (FB)
  // aperture keyword followed by a float value which determines the
  // depth of the sharpness zone. Large apertures give a lot of blurring,
  // while narrow apertures will give a wide zone of sharpness. .05 infocus. 1.5 lots of blur
    aperture 1.25
    focal_point 0
    //maximum number of samples, stops shooting rays when a certain degree of confidence has been reached 
    blur_samples 50 //256
    confidence 0.9
    // Larger confidence values give more samples, slower traces and better images.
    // The variance value specifies an acceptable tolerance on the variance of the samples taken so far.
    // In other words, the process of shooting sample rays is terminated when the estimated color value
    // is very likely (as controlled by the confidence probability) near the real color value. 

    variance 1/25  //256
    // Smaller variance thresholds for more samples.
  #end
}


#declare _z_ = -<300, 500, 104> ;
#declare _x_ = vnormalize(vcross(y,_z_))*50;
#declare _y_ = vnormalize(vcross(_z_,_x_))*50;

#if (0)
  light_source { <300, 500, 104> color white
    area_light _x_,_y_, 13,13 adaptive 0 jitter circular
    #if (0) media_attenuation on #end
  }
  #end

#declare _z_ = -<-700+208, 500, 104> ;
#declare _x_ = vnormalize(vcross(y,_z_))*50;
#declare _y_ = vnormalize(vcross(_z_,_x_))*50;
  #if (0)
  light_source { <-700+208, 500, 104> color white
    area_light _x_,_y_, 13,13 adaptive 0 jitter circular
    #if (0) media_attenuation on #end
  }
  #end
#switch ( Quality )
  #case ( Final_town ) 
    light_source { vaxis_rotate(<700, 500, 202>,y,-10) color white area_light 70*y, 70*z, 5, 5 adaptive 0 jitter rotate 45*y 
      #if (Use_Photons) photons { refraction on } #end
    }
    #declare nice = color rgb < .4, .7 ,1>*1.5;
    #declare nice2 = color rgb < 0,0,1>*1.2 ;
    #declare grad_tex =
    texture {
      
      pigment { gradient y color_map { [ 0 nice ] [ 0.1 nice2 ] [ 0.3 color rgb 0 ] } }
      
      //finish { basic_finish }
      finish { ambient 0.07 diffuse 0.95 brilliance 1 phong 0 phong_size 40 reflection 0 }
      scale 200
    }
    #break
  #case ( Final_space )
    light_source { <700, 500, 200> color white area_light 50*y, 50*z, 5, 5 adaptive 0 jitter }
    #declare nice = color rgb <1, .8, .6>;
    #declare nice2 = color black;
    #declare grad_tex =
    texture {
      pigment { gradient y color_map { [ 0.0 color nice ] [ 0.4 color _red ] [ 0.8 color black ] } }
      finish { basic_finish }
      scale 200
    }
    #break
  #case ( Final_diver )
    light_source { <700, 500, 0> color white area_light 50*y, 50*z, 5, 5 adaptive 0 jitter }
    #declare nice = color rgb <1, .8, .6>;
    #declare nice2= color black;
    #declare grad_tex =
    texture {
      pigment { gradient y color_map { [ 0.0 color nice ] [ 0.4 color _green ] [ 0.8 color black ] } }
      finish { basic_finish }
      scale 200
    }
    #break
  #case ( Preview_town )
    light_source { <700, 500, 0> color white media_interaction off rotate 45*y }
    #declare nice = color white;
    #declare nice2 = color rgb <.2, .2, .8>;
    #declare grad_tex =
    texture {
      pigment { gradient y color_map { [ 0.0 color white ] [ 0.6 color nice2 ] } }
      finish { basic_finish }
      scale 200
    }
    #break
  #case ( Preview_space )
    light_source { <700, 500, 0> color white }
    #declare nice = color rgb <1, .8, .6>;
    #declare nice2= color black;
    #declare grad_tex =
    texture {
      pigment { gradient y color_map { [ 0.0 color nice ] [ 0.4 color _red ] [ 0.8 color black ] } }
      finish { basic_finish }
      scale 200
    }
    #break
  #case ( Preview_diver )
    light_source { <700, 500, 0> color white }
    #declare nice = color t_cyan;
    #declare nice2= color _blue;
    #declare grad_tex =
    texture {
      pigment { gradient y color_map { [ 0.0 color t_cyan ] [ 0.4 color t_cyan ] [ 0.8 color _blue ] } }
      finish { basic_finish }
      scale 200
    }
    #break
  #case ( Building_test )
    light_source { <700, 500, 0> color white }
    #declare nice = color white;
    #declare nice2 = color rgb <.2, .2 ,.8>;
#end

box { <-800, -80, -800> <800, 0, 900> texture { pigment { color nice } } 

finish { ambient 0.07 diffuse 0.95 brilliance 1 phong 0 phong_size 40 reflection 0 }
//finish { basic_finish }
}
#declare poolhole =
difference {
// the floor
  box { <-800, -80, -800> <800, 0, 900> }
  box { <0, -72, 0> <240, 1, 240> translate <-16,0,-16> }
  texture { pigment { color nice } } finish { basic_finish }
}

#if ( Quality < 7 )
  // the "enclosing world"
  box { <-750, -1, -750> <750, 750, 850> hollow
    texture { pigment { color white } } finish { basic_finish } }
  // the background
  union {
    box { <-800, -2, 849> <800, 800, 851>
      texture { finish { basic_finish } pigment { color nice2 } } }
    difference {
      box { <-800, 0, 649> <800, 200, 849> }
      cylinder { -805*x, 805*x, 200 translate <0, 200, 649> }
      texture { grad_tex }
      bounded_by { box { <-805, -1, 648> <805, 201, 850> } }
    }
  }
#end


//1x1 brick = 8x8x9.5

#declare beachball =
sphere {
  <0,0,0>, 1
  texture {
    pigment {
      radial
      frequency 3
      color_map {
        [0.00 color rgb <1.0,0.4,0.2> ]
        [0.33 color rgb <0.2,0.4,1.0> ]
        [0.66 color rgb <0.4,1.0,0.2> ]
        [1.00 color rgb <1.0,0.4,0.2> ]
      }
    }
    finish { ambient 0.4 phong .5 phong_size 450 roughness 0.05 reflection 0.05 }
  }
}
///////////////////////////// LEGO Man \\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\
#declare hhead = union {
 object { head_bp01(0) }      // age only     yellow_tex - with face  
 object { male_hair(black_tex) rotate y*-90 translate <0,6,0> }

 object { helmet(white_tex) rotate y*-90 translate <0,7.17,.05> }
 object { vizor_1(t_cyan_tex) rotate y*-90 translate <0,7,0> }
}

////////////////////// SEAWATER thanks to Cousin Ricky \\\\\\\\\\\\\\\\\\\\\\\\
//#include "shapes.inc" //required by shapes2.inc
#include "shapes2.inc"
#declare c_H2O_abs = rgb <0.272, 0.046, 0.010>; //at 1 meter
#declare c_Sea = <0.004, 0.012, 0.020>; //H2O scattering trial&error
#declare n_Sea = normal {
         function { f_ridge (x, y, z, 0.1, 1.0, 7, 0.7, 0.7, 0) } 2
//   function { f_ridged_mf (x, y, z, 0.1, 3.0, 7, 0.7, 0.7, 2) } 2
}
 //f_ridge = function { internal(58) }
// Parameters: x, y, z 
    // Six extra parameters required:
    // 1. lambda 
    // 2. octaves 
    // 3. omega 
    // 4. offset 
    // 5. Ridge
    // 6. noise
// Parameters: x, y, z
    // Six extra parameters required:                          
    // 1. H 
    // 2. Lacunarity 
    // 3. octaves
    // 4. offset 
    // 5. Gain 
    // 6. noise
#declare ior_NaCl_H2O = 1.34; //35g/l
#declare seawater = material {
       texture
       {  pigment { rgbf 1 }
          finish
          {  reflection { 0 0.5 fresnel } conserve_energy
             specular 1 roughness 0.01
          }
          #if (1) normal { n_Sea } #end
       }
       interior
       {  #if (1) ior ior_NaCl_H2O #end
          media 
          {  absorption c_H2O_abs
             #if (1) scattering { 3, c_Sea } #end
             method 3
             intervals 1
             samples 3, 3
             aa_level 2         
          }
       }
}
#declare poolwater = material {
       texture
       {  pigment { rgbf 1 }
          finish
          {  reflection { 0 0.1 fresnel } conserve_energy
             specular .052 roughness 0.01
          }
          #if (1) normal { n_Sea scale 7 } #end
       }
       interior
       {  #if (1) ior ior_NaCl_H2O #end
          media 
          {  absorption c_H2O_abs
             #if (1) scattering { 3, c_Sea } #end
             method 3
             intervals 1
             samples 3, 3
             aa_level 2         
          }
       }
}

#declare lightsaber = material {
texture
       {  pigment { rgbf 1 }
          finish
          {  reflection { 0 0.5 fresnel } conserve_energy
             specular 1 roughness 0.01
          }
          #if (1) normal { n_Sea } #end
       }
       interior
       {  #if (0) ior 1.5 #end
          media 
          {  //absorption <0.272, 0.046, 0.010>
             emission <.1, .1, 1>
             #if (1) scattering { 3, <0.004, 0.012, 0.020> } #end
             method 3
             intervals 1
             samples 3, 3
             aa_level 2         
          }
       }
}
#declare P= text {
   ttf
   "povlogo.ttf", "P",
   1, 0
   scale <8,8,1>
}
#declare PP= pigment {
   object {
      P
      color rgb 1
      color rgb <0.92,.9,.98>
    }
    warp {repeat x}
    warp {repeat y}
}
#declare PP2= pigment {
   object {
      P
      color rgb 1
      color rgb 0
    }
    warp {repeat x}
    warp {repeat y}
}

#declare greyplaid = 
texture {
    pigment { uv_mapping
      gradient x
      pigment_map{
        [1/10 rgb 0][1/10 gradient y
          colour_map{
            [1/10 rgb 0]
            [1/10 rgb <0.8,.81,.8>]
          }
        ]
      }
      scale <1/20,1/20,1>
    }
    finish { lego_finish }
}
#declare larmrot = <0,-15,35>;
#declare rarmrot = <0,5,-20>;

#declare handxrot = -30;
#declare lhandzrot = -90;
#declare rhandzrot = 90;

#declare legxrot = 0;

#declare shoulder = 7.0;
#macro legoman(T)
  union {
    object { hand(white_tex) rotate z*lhandzrot rotate x*handxrot translate <2.6,-8,-4.0>
      rotate larmrot translate <shoulder,14,0> }
    object { hand(white_tex) rotate z*rhandzrot rotate x*handxrot translate <-2.6,-8,-4.0>
      rotate rarmrot translate <-shoulder,14,0> }

    object { left_arm(T) rotate larmrot translate <shoulder,14,0> }
    object { right_arm(T) rotate rarmrot translate <-shoulder,14,0> }
    object { left_leg(greyplaid) rotate x*legxrot }
    object { right_leg(greyplaid) rotate x*legxrot }
    object { leg_joiner(grey_tex) }
    object {
    #if (0)
      difference {
        object { body(T) }
        object { P translate <-2.4,2,-4.2> }
      }
    #else body(T) #end
      translate <0,5,0>
    }
    object { hhead translate <0,17.4,0> }
  }
#end    
#macro legoman1(T)
  union {
    object { hand(white_tex) rotate x*handxrot translate <2.6,-8,-4.0>
      rotate larmrot translate <shoulder,14,0> }
    object { hand(white_tex) rotate x*handxrot translate <-2.6,-8,-4.0>
      rotate rarmrot translate <-shoulder,14,0> }

    object { left_arm(T) rotate larmrot translate <shoulder,14,0> }
    object { right_arm(T) rotate rarmrot translate <-shoulder,14,0> }
    object { left_leg(greyplaid) }
    object { right_leg(greyplaid) }
    object { leg_joiner(grey_tex) }
    object {
    #if (0)
      difference {
        object { body(T) }
        object { P translate <-2.4,2,-4.2> }
      }
    #else body(T) #end
      translate <0,5,0>
    }
    object { hhead translate <0,17.4,0> }
    
    object { stwa_lightsaber(T_Chrome_3C) rotate x*-15 translate z*-3.0 rotate x*handxrot
      translate <2.6,-8,-4.0> rotate larmrot translate <shoulder,14,0> } 
    #if (10)  // saber ON   
    object {
      cylinder { 0, 15*y, 1.5 }
      hollow material { seawater }
      //material { lightsaber }
      translate y*9.5
      rotate x*-15 translate z*-3.0 rotate x*handxrot
      translate <2.6,-8,-4.0> rotate larmrot translate <shoulder,14,0>
    }
    #end
    #if (0) // hammer
      object { hammer(black_tex) rotate y*90 rotate x*-15 translate <0,-5,-3.0> rotate x*handxrot
        translate <-2.6,-8,-4.0> rotate rarmrot translate <-shoulder,14,0> }
        
    #else
      object { stwa_lightsaber(T_Brass_3C) rotate x*-15 translate z*-3.0 rotate x*handxrot
        translate <-2.6,-8,-4.0> rotate rarmrot translate <-shoulder,14,0> } 
    #if (10)  // saber ON     
      object {
        cylinder { 0, 15*y, 1.5 }
        hollow //material { seawater }
        material { lightsaber }
        translate y*9.5
        rotate x*-15 translate z*-3.0 rotate x*handxrot
        translate <-2.6,-8,-4.0> rotate rarmrot translate <-shoulder,14,0>
      }
    #end
    #end
    light_group {
    light_source { <17.101, 15, -46.98465>*.75 color <.7,.6,1>*2.2 shadowless }   
    #if (1) object { P 
     texture { T_Chrome_3C } //chrome_tex }
     //hollow material { lightsaber }
     translate <-2.4,7,-4.2> } #end
     }
  }
#end
#macro skirt(color_tex)
   difference {
      box { <-8, 0, -4.2> <8, 3.5, 4.2> }
      box { <-10, -2, -5> <0, 20, 5> rotate -10*z translate <-8, 1, 0> }
      box { <0, -2, -5> <10, 20, 5> rotate 10*z translate <8, 1, 0> }
      texture { color_tex }
    }
#end
#macro legowoman(T)
  union {
    object { hand(skin_tex) rotate x*handxrot translate <2.6,-8,-4.0>
      rotate larmrot translate <shoulder,14,0> }
    object { hand(skin_tex) rotate x*handxrot translate <-2.6,-8,-4.0>
      rotate rarmrot translate <-shoulder,14,0> }

    object { left_arm(T) rotate larmrot translate <shoulder,14,0> }
    object { right_arm(T) rotate rarmrot translate <-shoulder,14,0> }
    object { left_leg(greyplaid) }
    object { right_leg(greyplaid) }
    object { leg_joiner(grey_tex) }
    object { skirt(t_orange_tex) translate <0,1.5,0> }
    object {
    #if (0)
      difference {
        object { body(T) }
        object { P translate <-2.4,2,-4.2> }
      }
    #else body(T) #end
      translate <0,5,0>
    }
                        //eyecolor,age
    object { head_fem01(<0,.5,.1>,0) translate <0,17.4,0> }
    object { hair_fem_long(red_tex) rotate y*-90 translate <0,17.4,0> }
        
    //object { hhead translate <0,17.4,0> }
    
    object { stwa_lightsaber(T_Brass_3C) rotate x*-15 translate z*-3.0 rotate x*handxrot
      translate <2.6,-8,-4.0> rotate larmrot translate <shoulder,14,0> } 
    #if (10)  // saber ON 
    object {
      cylinder { 0, 15*y, 1.5 }
      hollow //material { seawater }
      material { lightsaber }
      translate y*9.5
      rotate x*-15 translate z*-3.0 rotate x*handxrot
      translate <2.6,-8,-4.0> rotate larmrot translate <shoulder,14,0>
    }
    #end
    #if (0) // hammer
      object { hammer(black_tex) rotate y*90 rotate x*-15 translate <0,-5,-3.0> rotate x*handxrot
        translate <-2.6,-8,-4.0> rotate rarmrot translate <-shoulder,14,0> }
        
    #else
      object { stwa_lightsaber(T_Chrome_3C) rotate x*-15 translate z*-3.0 rotate x*handxrot
        translate <-2.6,-8,-4.0> rotate rarmrot translate <-shoulder,14,0> } 
    #if (10)  // saber ON 
      object {
        cylinder { 0, 15*y, 1.5 }
        hollow material { seawater }
        //material { lightsaber }
        translate y*9.5
        rotate x*-15 translate z*-3.0 rotate x*handxrot
        translate <-2.6,-8,-4.0> rotate rarmrot translate <-shoulder,14,0>
      } #end
    #end
    light_group {
    light_source { <17.101, 15, -46.98465>*.75 color <.7,.6,1>*2.2 shadowless }   
    #if (1) object { P 
     texture { T_Chrome_3C } //chrome_tex }
     //hollow material { lightsaber }
     translate <-2.4,7,-4.2> } #end
    }
  }
#end

#macro legogirl(T)
  union {
    object { hand(skin_tex) rotate x*handxrot translate <2.6,-8,-4.0>
      rotate larmrot translate <shoulder,14,0> }
    object { hand(skin_tex) rotate x*handxrot translate <-2.6,-8,-4.0>
      rotate rarmrot translate <-shoulder,14,0> }

    object { left_arm(T) rotate larmrot translate <shoulder,14,0> }
    object { right_arm(T) rotate rarmrot translate <-shoulder,14,0> }
    object { left_leg(greyplaid) }
    object { right_leg(greyplaid) }
    object { leg_joiner(grey_tex) }
    object { skirt(t_purple_tex) translate <0,1.5,0> }
    object {
    #if (0)
      difference {
        object { body(T) }
        object { P translate <-2.4,2,-4.2> }
      }
    #else body(T) #end
      translate <0,5,0>
    }
                        //eyecolor,age
    object { head_fem01(<0,.5,.1>,0) translate <0,17.4,0> }
    object { hair_fem_short(black_tex) rotate y*-90 translate <0,17.4,0> }
        
    //object { hhead translate <0,17.4,0> }
    
    object { stwa_lightsaber(T_Brass_3C) rotate x*-15 translate z*-3.0 rotate x*handxrot
      translate <2.6,-8,-4.0> rotate larmrot translate <shoulder,14,0> } 
    #if (10)  // saber ON 
    object {
      cylinder { 0, 15*y, 1.5 }
      hollow //material { seawater }
      material { lightsaber }
      translate y*9.5
      rotate x*-15 translate z*-3.0 rotate x*handxrot
      translate <2.6,-8,-4.0> rotate larmrot translate <shoulder,14,0>
    }
    #end
    #if (0) // hammer
      object { hammer(black_tex) rotate y*90 rotate x*-15 translate <0,-5,-3.0> rotate x*handxrot
        translate <-2.6,-8,-4.0> rotate rarmrot translate <-shoulder,14,0> }
        
    #else
      object { stwa_lightsaber(T_Chrome_3C) rotate x*-15 translate z*-3.0 rotate x*handxrot
        translate <-2.6,-8,-4.0> rotate rarmrot translate <-shoulder,14,0> } 
    #if (10)  // saber ON 
      object {
        cylinder { 0, 15*y, 1.5 }
        hollow material { seawater }
        //material { lightsaber }
        translate y*9.5
        rotate x*-15 translate z*-3.0 rotate x*handxrot
        translate <-2.6,-8,-4.0> rotate rarmrot translate <-shoulder,14,0>
      } #end
    #end
    light_group {
    light_source { <17.101, 15, -46.98465>*.75 color <.7,.6,1>*2.2 shadowless }   
    #if (1) object { P 
     texture { T_Chrome_3C } //chrome_tex }
     //hollow material { lightsaber }
     translate <-2.4,7,-4.2> } #end
     }
  }
#end   



/* /////////////////////////////////////
legolib new objs       //eyecolor,age
    object { head_fem01(<0,.5,.1>,0) translate <0,17.4,0> }
    object { hair_fem_short(black_tex) rotate y*-90 translate <0,17.4,0> }
    object { hair_fem_long(red_tex) rotate y*-90 translate <0,17.4,0> }
    
    material lib:
    skin_tex
*/


#macro pceoff(pce,Start,Offset,n)
  #local i = 0;
  #while (i<n)
    object {
      pce
      translate Start+(Offset*i)
    }
    #local i=i+1;     
  #end
#end
#macro pceoff2(pce,pce2,Start,Offset,n)
  #local i = 0;
  #while (i<n)
    object {
      #if (mod(i,2)) pce2
      #else pce #end
      translate Start+(Offset*i)
    }
    #local i=i+1;     
  #end
#end
#macro pceoff3(pce,pce2,pce3,Start,Offset,n)
  #local i = 0;
  #while (i<n)
    object {
      #if (mod(i,3)=2) pce3
      #else #if (mod(i,3)=1) pce2
      #else pce #end #end
      translate Start+(Offset*i)
    }
    #local i=i+1;     
  #end
#end


//center cross
//box { <-800, 0, -1> <800, .1, 1> texture { cyan_tex } finish { basic_finish } rotate <0, 0 ,0> }
//box { <-1, 0, -800> <1, .1, 800> texture { cyan_tex } finish { basic_finish } rotate <0, 0 ,0> }
                        
   
#declare palmtree =
union {
     object { h_block1_1(brown2_tex) }
     object { h_block1_1(brown2_tex) rotate y*20 translate y*9.5*1}
     object { h_block1_1(brown2_tex) rotate y*40 translate y*9.5*2}
     object { h_block1_1(brown2_tex) rotate y*60 translate y*9.5*3}
     object { h_block1_1(brown2_tex) rotate y*80 translate y*9.5*4}
     object { h_block1_1(brown2_tex) rotate y*100 translate y*9.5*5}
     object { h_block1_1(brown2_tex) rotate y*120 translate y*9.5*6}
     object { h_block1_1(brown2_tex) rotate y*140 translate y*9.5*7}
     object { h_block1_1(brown2_tex) rotate y*160 translate y*9.5*8}
     
     object { palm_leaves(green_tex) rotate < 0,0,0 > translate < 0,9.5*9,0 > }
     object { palm_leaves(green_tex) rotate < 0,90,0 > translate < 0,9.5*9+3.16,0 > }
     object { palm_leaves(green_tex) rotate < 0,180,0 > translate < 0,9.5*9+6.33,0 > }
     object { palm_leaves(green_tex) rotate < 0,270,0 > translate < 0,9.5*9+9.5,0 > }
}

#macro legogirl2(T)
  union {
    object { hand(skin_tex) rotate x*handxrot translate <2.6,-8,-4.0>
      rotate larmrot translate <shoulder,14,0> }
    object { hand(skin_tex) rotate x*handxrot translate <-2.6,-8,-4.0>
      rotate rarmrot translate <-shoulder,14,0> }

    object { left_arm(T) rotate larmrot translate <shoulder,14,0> }
    object { right_arm(T) rotate rarmrot translate <-shoulder,14,0> }
    object { left_leg(greyplaid) }
    object { right_leg(greyplaid) }
    object { leg_joiner(grey_tex) }
    object { skirt(t_purple_tex) translate <0,1.5,0> }
    object { body(T) translate <0,5,0> }
                        //eyecolor,age
    object { head_fem01(<0,.5,.1>,0) translate <0,17.4,0> }
    object { hair_fem_short(black_tex) rotate y*-90 translate <0,17.4,0> }
    
    object { stwa_lightsaber(T_Chrome_3C) rotate x*-15 translate z*-3.0 rotate x*handxrot
        translate <-2.6,-8,-4.0> rotate rarmrot translate <-shoulder,14,0> } 
    #if (10)  // saber ON 
      object {
        cylinder { 0, 26*y, 1.5 }
        hollow //material { seawater }
        material { lightsaber }
        translate y*9.5
        rotate x*-15 translate z*-3.0 rotate x*handxrot
        translate <-2.6,-8,-4.0> rotate rarmrot translate <-shoulder,14,0>
      }
    #end    
  }
#end   



#macro poolscene()
                 #declare larmrot = <0,-15,35>;
                 #declare rarmrot = <0,5,-20>;
                 object { legogirl2(t_blue_tex) rotate y*-10 scale .9 translate <32, 10, -40> }

                 object { palmtree translate <-40,-22,160> }
                 object { bush(green_tex) rotate y*23 translate <-60,0,90> }
                 object { bush(green_tex) translate <-45,0,195> }
                 object { bush(green_tex) scale .5 rotate y*17 translate <78,0,290> }
                 
                 object { tree_2(green_tex) translate <-50, 0, 450> }
                 object { tree_1(green_tex) scale .8 translate <0, 0, 500> }
                 object { tree_3(green_tex) scale .95 translate <70, 0, 425> }
                 union {
                          object { motorbike_body(blue_tex) translate <0,0,0> }
                          object { shuttle_wheel() scale <1.6,1.6,1> translate <0, 0,0> }
                          object { bicycle_wheel(white_tex) translate <-36, 0,0> }
                          cylinder { -2.4*2.5*z, 2.4*2.5*z, 1.05 translate <-35.54, 0,0> texture { white_tex } }
                          //  rotate z*-1
                          translate <140, 9,-100>
                 }
                 #declare legxrot = 21;
                 #declare larmrot = <36,0,0>;
                 #declare rarmrot = <36,0,0>;
                 #declare lhandzrot = 90;
                 #declare rhandzrot = -90;
                 object { legoman(mint_tex) rotate y*90 translate <140-13.5, 20-1.3,-100> }
                 
                 union {
                  object { helmet(white_tex) rotate y*-90 translate <0,7.17,.05> }
                  object { vizor_1(t_cyan_tex) rotate y*-90 translate <0,7,0> }
                  scale .9
                 translate <32+16, -1.0, -40>
                 }
#end
#macro initsaucer(stng)
    #local swas = setting;
    #declare _s_saucer = 
      union {
        object { s_saucer_section(white_tex) translate < 4,25,-4 > rotate < 0,0,0 > }
        object { s_saucer_section(white_tex) translate < 4,25,-4 > rotate < 0,90,0 > }
        object { s_saucer_section(white_tex) translate < 4,25,-4 > rotate < 0,180,0 > }
        object { s_saucer_section(white_tex) translate < 4,25,-4 > rotate < 0,270,0 > }

        #declare setting = stng;
        object { s_saucer_bottomsection(white_tex) translate < 4,0,4 > rotate < 0,0,0 > }
        object { s_saucer_bottomsection(white_tex) translate < 4,0,4 > rotate < 0,90,0 > }
        object { s_saucer_bottomsection(white_tex) translate < 4,0,4 > rotate < 0,180,0 > }
        object { s_saucer_bottomsection(white_tex) translate < 4,0,4 > rotate < 0,270,0 > }
    }
  #declare setting = swas; 
#end




#declare LRoad_RoadWidth =       array[3] {280,306,360 }         // The width of the road.
#declare LRoad_StripeInterval =  array[3] { 64, 64, 64 }         // The distance between each stripe-interval.
#declare LRoad_CornerRadius =    array[3] { 23, 36, 63 }         // The distance from the outer edge of the road to the inner edge of the innermost stripe, not including the center stripes.
#declare LRoad_MajorArc =        array[3] { 52,  0, 10 }         // The distance from the intersection that the road begins to curve.
#declare LRoad_WalkDistance =    array[3] { 75, 75, 75 }         // The distance from the intersection to the center of a crosswalk.
#declare LRoad_WalkWidth =       array[3] {234,234,234 }         // The width of the crosswalk.
#declare LRoad_WalkLength =      array[3] { 60, 60, 60 }         // The length of the crosswalk.
#declare LRoad_WalkStripeWidth = array[3] { 25, 25, 25 }         // The width of a crosswalk stripe.
#declare LRoad_DistanceUnit =    10;                             // The unit of distance equivalent to 1 foot. Used when determining super-elevation.
#declare LRoad_RoadColor =       rgb 0.887;                      // The principal color of the road surface.
#declare LRoad_EdgeColor =       rgb <0.12,0.827,0.23>;       // The shoulder color.
#declare LRoad_StrpColor =       rgb 1.5;                                // The stripe marker color.

/*  (  2.15
		array,
		1,			// Type of road. "9-Stud" is 1, "8-Stud" is 2 and "7-Stud" is 3.	(integer)
		no,			// Enables/disables debug information.	(boolian)
	)


( 2.5.2    with Lego finish
		roadCoo,	// An array of vectors containing the starting points of the intersecting roads.	(array)
				// ... There can be as many as you want. List them in clockwise order when looking down from the top.
				// ... Since the intersections are flat, the vectors are two-dimensional instead of three-dimensional, and contain only the x and z coordinates.
				// ... Make sure to increment the array counter when adding or subtracting elements.
		roadHgh,	// The height of the road above the x-z plane.						(float)
		roadTyp,	// The type of road. 0 = "9-Stud"; 1 = "8-Stud"; 2 = "7-Stud".				(integer)
		showCrs,	// Enable/disable crosswalks.								(boolean)
		showBed,	// Enable/disable road embankments.							(boolean)
	)
	  */
  
#declare roads = array[2] { < -50000,0,0 >,< 50000,0,00 > }
#if (0)
    #include "LegoRoad_macro252.inc"
    #declare LRoad_WalkWidth =    array[3] { 70,70,70 }	// The width of the crosswalk.
    #declare LRoad_WalkLength =   array[3] {234,234,234}
    object { LRoad_Intersection_Macro252(roads,.1,1,1,0) scale < .4,1,.44 > translate <7,0,-126> }
#else #if (0) #include "LegoRoad_macro215.inc"
   object { LRoad_Intersection_Macro(roads,1,0)
              scale < .4,1,.5 > translate <32,0,-126> }
#end #end
//object { bush(green_tex) scale .3 rotate y*-113 translate <65,0,-222> }

///////////////////////////////////////////////////// TgQ \\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\
#declare normhf = 0;
#include "TQ_water.pov"



#declare BSiz=<240,72,240>; // box size
#declare TilSiz=<4,8,1>;    //Size of tile (x,y)
#declare Grt=0.5;         //Width of grout
#declare TilCol=rgb <.6,.6,1>;  //Tile colour
#declare GrtCol=rgb 1;   

#include "TQ_BoxUV.pov"
#declare pool_box_CSG =
difference {
    box { <-8, -72, -8> <232, 0, 232> } // legoworld hole  +8
    box { <0, -64, 0> <224, 1, 224> }
    texture { TQ_BoxUV basic_finish }
    translate <-8,0,-8>
}


#declare BSiz=<8,72,232>;
#include "TQ_BoxUV.pov"
  
#declare pool_box =
union {
   box { 0 <8,72,232> texture { TQ_BoxUV basic_finish } translate <-16,-72,-8> }
   box { 0 <8,72,232> texture { TQ_BoxUV basic_finish } rotate y*90 translate <-8,-72,224> }
   box { 0 <8,72,232> texture { TQ_BoxUV basic_finish } translate <216,-72,-8> }
   box { 0 <8,72,232> texture { TQ_BoxUV basic_finish } rotate y*90 translate <-16,-72,-8> }
   //floor
   #declare BSiz=<240, 240, 8>;
   #include "TQ_BoxUV.pov"
   box { 0 <240, 240, 8> texture { TQ_BoxUV basic_finish } rotate x*90  translate <-16,-64,-16> }
}
//object { pool_box translate y*4 } 
///////////////////////////////////////////////////// TgQ \\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\


#declare pool =                
union {
   object { pool_box }
   #if (normhf) object { TQ_water_hf }
   #else object { TQ_water_n }
   #end
   object { beachball scale 8.5 rotate z*45 rotate y*-55 translate <53,6.3,100> } //<30,6.5,55> }
   translate y*4
}

#include "transport.pov"

#declare currpos = <68,49,300>;
//#declare currpos = 0;
//#declare currpos = <100,0,-139>;

#declare yrot = 0; // degrees rotation - left 
#declare transaxis = <-15,yrot,0>;
#declare rudang = 0;     // + left  turns front strut also

#declare elevang = 3;           // - down
#declare TF = .75;
#declare tscale = 4;
#declare WheelBase = 11.2*tscale;
//#declare tport =

#macro tport()
        object { transport()
        
          translate x*-6.2      // rotate on rear wheels
          translate y*-3
          rotate transaxis
          translate y*3
          translate y*-0.27     // wheels touch y 0
          
           scale tscale translate currpos
        }
        
        //area thrust light source array len .35
        Thrust_light(<12.2,2.73,0>)
        
        #declare hp = <(-7-6.2)*tscale,2.73*tscale,0>+currpos;
        #declare Target = <-150,20,400>;
        
        laser(hp, Target,3*tscale,<.1,.02,.1>)
#end


#declare legxrot = 21;
#declare larmrot = <50,0,0>;
#declare rarmrot = <60,0,0>;
#declare lhandzrot = 90;
#declare rhandzrot = -90;


#declare pilot =
union {
   object { head_bp01(0) translate <0,17.4,0> }      // age only     yellow_tex - with face  
   object { male_hair(black_tex) rotate y*-90 translate <0,6,0> translate <0,17.4,0> }
   object { body(yellow_tex) translate <0,5,0> } 
   
   object { hand(skin_tex) rotate z*lhandzrot rotate x*handxrot translate <2.6,-8,-4.0>
                                              rotate larmrot translate <shoulder,14,0> }
        
   object { hand(skin_tex) rotate z*rhandzrot rotate x*handxrot translate <-2.6,-8,-4.0>
                                              rotate rarmrot translate <-shoulder,14,0> }
   
   object { left_arm(yellow_tex) rotate larmrot translate <shoulder,14,0> }
   object { right_arm(yellow_tex) rotate rarmrot translate <-shoulder,14,0> }   
      
   rotate y*90
   scale 1/8 translate <-1,1,0>
   // inside, now what tport is doing
   translate y*-3
   rotate transaxis
   translate y*3
   //translate y*-0.27
   scale tscale translate currpos
}
#if (0)               
  poolscene()
  initsaucer(1) //setting 0-4       for bottom section    1 or its takes way too long
  object { _s_saucer scale .5 rotate y*-7 translate <-150,0,400> }
  tport()
  object { pool }                 
  object { pilot}
#end
/*                 
Media:
      Water: TgQ
      Absorption: Cousin Ricky
Rune's Particle adaptation:
      Laser: cylindrical
      Exhaust: spherical
UV tile: TgQ
Lego CSG: Anton
*/





/*Use Poseray to get the Dolphin from:
http://www.3dnuts.com/models.shtml
    */
#if(0)

      #include "dolphin_geom.inc"
      #declare dolphin7 =
      object {
      
        dolphin_7 
        texture { grey_tex }
        scale .17 rotate x*-90 rotate y*90
        //translate <90,-1.3,150>  
        
        rotate z*-35 
        rotate y*-45
        translate <150,-6,75>
        
      }
      
      echov(min_extent(dolphin7))
      echov(max_extent(dolphin7))
      cr()
      echo("=")
      echov(max_extent(dolphin7)-min_extent(dolphin7))
      cr()
      
      object { dolphin7 }
#end


union {
object { flowerbase(green_tex) scale 1 rotate < 0,0,0 > translate < 0,0,0 > }
object { flower(yellow_tex)
        rotate z*180
        translate < 0,8.09999,0 >
        rotate -15*z
        translate < 3,4.899999,0>
}
object { flower(blue_tex) 
        rotate z*180
        translate < 0,10.999999,0 >
        rotate -15*z
        translate < 3,4.899999,0>
        rotate 240*y
}
object { flower(red_tex)
        rotate z*180
        translate < 0,12.999999,0 >
        rotate -15*z
        translate < 3,4.899999,0>
        rotate 120*y
  }
  rotate y*115
  translate <40,0,42>
}



#declare larmrot = <40,0,0>;
#declare rarmrot = <40,0,0>;

#declare handxrot = -30;
#declare lhandzrot = -90;
#declare rhandzrot = 90;

#declare legxrot = 90;
#declare shoulder = 6.4;

#macro spacehead(T)
union {
   object { vizor_1(t_clear_tex) rotate y*-90 translate <0,23.8,0> } 
   object { old_helmet(T) rotate y*-90 translate <0,22.5,-1> }
    
   object { head_bp01(0) translate <0,17.4,0> }
   rotate y*-40
   translate y*1.4
   }
#end   

#macro spacepilot(T)
  union {
   
    spacehead(T)
    object { body(T) translate <0,5,0> } 
   
    object { hand(T) rotate z*lhandzrot rotate x*handxrot translate <2.6,-8,-4.0>
                                             rotate larmrot translate <shoulder,14,0> }
       
    object { hand(T) rotate z*rhandzrot rotate x*handxrot translate <-2.6,-8,-4.0>
                                             rotate rarmrot translate <-shoulder,14,0> }
   
    object { left_arm(T) rotate larmrot translate <shoulder,14,0> }
    object { right_arm(T) rotate rarmrot translate <-shoulder,14,0> }
  
    object { left_leg(T) rotate x*legxrot }
    object { right_leg(T) rotate x*legxrot }
    object { leg_joiner(T) } 
 
    #if (1)
      object
      { P 
       texture { dark_grey2_tex }
       translate <-2.4,7,-4.2>
      }
    #end
    rotate y*90
    translate < 22,3.16*2,-12 >
  }
#end








#declare age = 0;
#declare _f_block1_1 = object { 
#if (Use_Photons) f_block1_1_ph(t_red_tex)
#else f_block1_1(t_red_tex)
#end
}


// ship mount laser 
// THE MOUNT !!!!!!!!!!!!!!!!!
#declare _fsblock1_2 = object { fsblock1_2(white_tex, 0) }
// the GUN
#declare _laser_mount = object { laser_mount(dark_grey2_tex) }

//transparent barrel!!!!!!!!     with ID of 3.5 looks like
#declare _hrblock1_1 = object {
#if (Use_Photons) hrblock1_1_ph(t_dark_green_tex)
#else hrblock1_1(t_dark_green_tex)
#end
 
}



//#declare space1 =
union {
  //front cannons
  object { fpblock1_2(dark_grey2_tex) rotate < 0,90,0 > translate < -40,3.16,8 > }
  
  object { jet_engine1(dark_grey2_tex,0) rotate < 0,0,0 > translate < -16,-3.16,0 > }
  object { jet_engine1(dark_grey2_tex,0) rotate < 0,180,0 > translate < -8,-3.16,8 > }
  
  object { f_block2_8(dark_grey2_tex) translate < -40,0,0 > }
  object { f_block2_4(dark_grey2_tex) translate < -40+8,3.16,0 > }
  
  
  object { slope2_3(dark_grey2_tex) translate < -40+16,3.16*2,0 > 
        #if (Use_Photons) photons { collect on } #end
  }
   #if (1) object { P
     texture { white_tex }
     rotate y*90
     rotate z*-65
     translate < -40+16,3.16*2+4.12,6 > 
   } #end
  
  
  
   object { h_block1_2(dark_grey2_tex) rotate y*-90 translate < 0,3.16*2,0 > }
  
  
   object { f_left_wing4_4(dark_grey2_tex) translate < -16,3.16,-24 > }
   object { f_right_wing4_4(dark_grey2_tex) translate < -16,3.16,8 > }
  
    object { f_left_wing4_4(dark_grey2_tex) translate < 8,3.16,-48 > }
    object { f_block4_6(dark_grey2_tex) rotate < 0,90,0 > translate < 16,3.16,24 > }
                                                                   object { f_block1_6(dark_grey2_tex,0) rotate < 0,90,0 > translate < 16+32,3.16,24 > }
   object { f_right_wing4_4(dark_grey2_tex) translate < 8,3.16,8+24 > }
   
  //tail
   object { tail_s(dark_grey2_tex) translate < 32,3.16*2,0 > }
   object { f_block2_6(dark_grey2_tex) rotate < 0,90,0 > translate <48,3.16*8,24 > }
   object { _f_block1_1 translate < 56,3.16*9,-16 > }
   object { _f_block1_1 translate < 56,3.16*9,24 > }
   
   
  
  // THE MOUNT
  object { fsblock1_2(dark_grey2_tex, 0) rotate y*-90 translate < 0,3.16*5,0 > }
  
  object { _laser_mount rotate z*-90 translate <0-9.5,26,4> }
  object { _hrblock1_1 rotate z*-90 translate <-10-9.5,26,4> } 
  
  
  object { f_block1_4(dark_grey2_tex,0) translate < 8,3.16*2,32 > }
  object { f_block1_4(dark_grey2_tex,0) translate < 8,3.16*2,-24 > }
                                           //rot,age
  object { steering_column(dark_grey2_tex, black_tex,0,0) translate < 8,3.16*2,16 > }
  object { steering_column(dark_grey2_tex, black_tex,0,0) translate < 8,3.16*2,-16 > }
  object { sirens(dark_grey2_tex) rotate < 0,180,0 > translate < 32,3.16*2,40 > }
  object { sirens(dark_grey2_tex) translate < 32,3.16*2,-32 > }
  //hole fix
  object { f_block1_1(dark_grey2_tex) translate < 32,3.16*3,32 > }
  object { f_block1_1(dark_grey2_tex) translate < 32,3.16*3,-24 > }

  spacepilot(white_tex)
  translate z*-4 // center
  rotate <-12,-30,0>
  //rotate <-90,0,30>
  translate <-15,40,0>

}

//side buttons
//object { h_block1_2_buttoned(grey_tex) translate < 0,0,0 > }

#declare hp = <-5-9.5,26,0>;  // 4 + -4
#declare hp = vaxis_rotate(hp,x,-12)  ;
#declare hp = vaxis_rotate(hp,y,-30)  ;

#declare hp = hp + <-15,40,0>;
#declare Target = vaxis_rotate(vaxis_rotate(<-150,26,0>,x,-12),y,-30)+y*40 ;
//laser(hp, Target,2,<.015,.005,.8>*.4)    //    red/blue
laser(hp, Target,3,<.102,.3,.102>*.2) // green

//laser(hp, Target,3,<.3,.1,.1>*.25)    //red

