// Persistence of Vision RayTracer version 3.1 Scene description file
// File:        TEXTURES_POSTER.POV
// Description: An empty scene for displaying the different textures into.
// Date:        2007/11/30
// Author:      Anton Raves

// This scene has been developed at a 16 x 9 aspect ratio (widescreen) and should therefore
// be rendered at such a output ratio too! For example you could use 640 x 360.

#declare Final_town    = 1;
#declare Final_space   = 2;
#declare Final_diver   = 3;
#declare Preview_town  = 4;
#declare Preview_space = 5;
#declare Preview_diver = 6;
#declare Building_test = 7;

#declare Quality = Final_town;
#declare radio = 1;
#declare setting = 4;

#include "material.lib"
#include "library.lib"

camera {
  location  <62.5, 80, -250>
  direction 2*z
  up        y
  right     hdtv*x
  look_at   <62.5, 45, 0>
}

#switch ( Quality )
  #case ( Final_town )
    light_source { <700, 500, 0> color (white) area_light 50*y, 50*z, 5, 5 adaptive 0 jitter rotate 45*y }
    #declare nice = color white;
    #declare nice2 = color rgb <.2, .2 ,.8>;
    #declare grad_tex =
    texture {
      pigment { gradient y color_map { [ 0.0 color nice ] [ 0.6 color nice2 ] } }
      finish { basic_finish }
      scale 200
    }
    #break
  #case ( Final_space )
    light_source { <700, 500, 0> color white area_light 50*y, 50*z, 5, 5 adaptive 0 jitter }
    #declare nice = color rgb <1, .8, .6>;
    #declare nice2 = color black;
    #declare grad_tex =
      pigment { gradient y color_map { [ 0.0 color nice ] [ 0.4 color _red ] [ 0.8 color black ] } }
      finish { basic_finish }
      scale 200
    }
    #break
  #case ( Final_diver )
    light_source { <700, 500, 0> color white area_light 50*y, 50*z, 5, 5 adaptive 0 jitter }
    #declare nice = color rgb <1, .8, .6>;
    #declare nice2= color black;
    #declare grad_tex =
    texture {
      pigment { gradient y color_map { [ 0.0 color nice ] [ 0.4 color groen ] [ 0.8 color black ] } }
      finish { basic_finish }
      scale 200
    }
    #break
  #case ( Preview_town )
    light_source { <700, 500, 0> color white media_interaction off rotate 45*y }
    #declare nice = color white;
    #declare nice2 = color rgb <.2, .2, .8>;
    #declare grad_tex =
    texture {
      pigment { gradient y color_map { [ 0.0 color white ] [ 0.6 color nice2 ] } }
      finish { basic_finish }
      scale 200
    }
    #break
  #case ( Preview_space )
    light_source { <700, 500, 0> color white }
    #declare nice = color rgb <1, .8, .6>;
    #declare nice2= color black;
    #declare grad_tex =
    texture {
      pigment { gradient y color_map { [ 0.0 color nice ] [ 0.4 color _red ] [ 0.8 color black ] } }
      finish { basic_finish }
      scale 200
    }
    #break
  #case ( Preview_diver )
    light_source { <700, 500, 0> color white }
    #declare nice = color t_cyan;
    #declare nice2= color _blue;
    #declare grad_tex =
    texture {
      pigment { gradient y color_map { [ 0.0 color t_cyan ] [ 0.4 color t_cyan ] [ 0.8 color _blue ] } }
      finish { basic_finish }
      scale 200
    }
    #break
  #case ( Building_test )
    light_source { <700, 500, 0> color white }
    #declare nice = color white;
    #declare nice2 = color rgb <.2, .2 ,.8>;
#end

// the floor
box { <-800, -2, -800> <800, 0, 900> texture { pigment { color nice } } finish { basic_finish } }

#if ( Quality < 7 )
  // the "enclosing world"
  box { <-750, -1, -750> <750, 750, 850> hollow
    texture { pigment { color white } } finish { basic_finish } }
  // the background
  union {
    box { <-800, -2, 849> <800, 800, 851>
      texture { finish { basic_finish } pigment { color nice2 } } }
    difference {
      box { <-800, 0, 649> <800, 200, 849> }
      cylinder { -805*x, 805*x, 200 translate <0, 200, 649> }
      texture { grad_tex }
      bounded_by { box { <-805, -1, 648> <805, 201, 850> } }
    }
  }
#end

// the bricks differently textured and aligned
union {
  object { h_block2_2(beige_tex) }
  object { h_block2_2(yellow_tex) translate <24, 0, 0> }
  object { h_block2_2(orange_tex) translate <48, 0, 0> }
  object { h_block2_2(green2_tex) translate <0, 19.2, 8> }
  object { h_block2_2(blue_tex) translate <24, 19.2, 8> }
  object { h_block2_2(black_tex) translate <48, 19.2, 8> }
  object { h_block2_2(white_tex) translate <0, 38.4, 16> }
  object { h_block2_2(grey_tex) translate <24, 38.4, 16> }
  object { h_block2_2(lt_grey_tex) translate <48, 38.4, 16> }
  object { h_block2_2(brown_tex) translate <0, 57.6, 24> }
  object { h_block2_2(brown2_tex) translate <24, 57.6, 24> }
  object { h_block2_2(cyan_tex) translate <48, 57.6, 24> }
  object { h_block2_2(dark_cyan_tex) translate <0, 76.8, 32> }
  object { h_block2_2(yellowgreen_tex) translate <24, 76.8, 32> }
  object { h_block2_2(blue2_tex) translate <48, 76.8, 32> }
  object { h_block2_2(orange_bright_tex) translate <72, 0, 0> }
  object { h_block2_2(red_tex) translate <96, 0, 0> }
  object { h_block2_2(dark_red_tex) translate <120, 0, 0> }
  object { h_block2_2(mint_tex) translate <72, 19.2, 8> }
  object { h_block2_2(purple_tex) translate <96, 19.2, 8> }
  object { h_block2_2(green_tex) translate <120, 19.2, 8> }
  object { h_block2_2(grey2_tex) translate <72, 38.4, 16> }
  object { h_block2_2(dark_grey2_tex) translate <96, 38.4, 16> }
  object { h_block2_2(t_black_tex) interior { ior 1.5 } translate <120, 38.4, 16> }
  object { h_block2_2(t_blue_tex) interior { ior 1.5 } translate <72, 57.6, 24> }
  object { h_block2_2(t_clear_tex) translate <96, 57.6, 24> }
  object { h_block2_2(t_cyan_tex) interior { ior 1.5 } translate <120, 57.6, 24> }
  object { h_block2_2(t_green_tex) interior { ior 1.5 } translate <72, 76.8, 32> }
  object { h_block2_2(t_old_clear_tex) interior { ior 1.5 } translate <96, 76.8, 32> }
  object { h_block2_2(t_orange_tex) interior { ior 1.5 } translate <120, 76.8, 32> }
  object { h_block2_2(t_red_tex) interior { ior 1.5 } translate <144, 0, 0> }
  object { h_block2_2(t_yellow_tex) interior { ior 1.5 } translate <168, 0, 0> }
  object { h_block2_2(t_yellowgreen_tex) interior { ior 1.5 } translate <192, 0, 0> }
  object { h_block2_2(t_white_tex) interior { ior 1.5 } translate <144, 19.2, 8> }
  object { h_block2_2(t_vizor_tex) interior { ior 1.5 } translate <168, 19.2, 8> }
  object { h_block2_2(blue_gold_tex) translate <192, 19.2, 8> }
  object { h_block2_2(chrome_tex) translate <144, 38.4, 16> }
  object { h_block2_2(conductive_tex) translate <168, 38.4, 16> }
  object { h_block2_2(copperish_tex) translate <192, 38.4, 16> }
  object { h_block2_2(gold_tex) translate <144, 57.6, 24> }
  object { h_block2_2(goldish_tex) translate <168, 57.6, 24> }
  object { h_block2_2(hologram_tex) translate <192, 57.6, 24> }
  object { h_block2_2(lt_blue_tex) translate <144, 76.8, 32> }
  object { h_block2_2(r_black_tex) translate <168, 76.8, 32> }
  object { h_block2_2(r_brown_tex) translate <192, 76.8, 32> }
  object { h_block2_2(r_grey_tex) translate <216, 0, 0> }
  object { h_block2_2(r_white_tex) translate <216, 19.2, 8> }
  object { h_block2_2(r_yellow_tex) translate <216, 38.4, 16> }
  object { h_block2_2(silverish_tex) translate <216, 57.6, 24> }
  object { h_block2_2(bnsf_green_tex) translate <216, 76.8, 32> }
  object { h_block2_2(lt_green_tex) translate <240, 76.8, 32> }
  rotate -35*y
}
